@@ -1,5 +1,13 @@
 from __future__ import annotations
 
+from enum import Enum
+
+
+class ErrorMSG(Enum):
+    SERVER_ERR = "Cannot connect to the server."
+    LOGIN_ERR = "Login to Xplora® API failed. Check your input!\n{}"
+    PHONE_MAIL_ERR = "Phone Number or Email address not exist"
+
 
 class Error(Exception):
     pass
@@ -46,10 +54,14 @@ class FunctionError(Error):
 
 
 class LoginError(Error):
-    def __init__(self, message: str, res: str = "") -> None:
-        self.message = message
-        self.res = res
-        super().__init__(self.message, self.res)
+    def __init__(self, message: str | ErrorMSG) -> None:
+        self.message = message if isinstance(message, str) else message.value
+        super().__init__(self.message)
 
     def __str__(self) -> str:
-        return f"{self.message} - {self.res}"
+        return self.message
+
+
+class PhoneOrEmailFail(LoginError):
+    def __init__(self, message: str = ErrorMSG.PHONE_MAIL_ERR) -> None:
+        super().__init__(message)
